@@ -1,11 +1,9 @@
-# encoding: utf-8
 """
 A simple utility to import something by its string name.
 """
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from ipython_genutils.py3compat import cast_bytes_py2, string_types
 
 def import_item(name):
     """Import and return ``bar`` given the string ``foo.bar``.
@@ -16,25 +14,24 @@ def import_item(name):
     Parameters
     ----------
     name : string
-      The fully qualified name of the module/package being imported.
+        The fully qualified name of the module/package being imported.
 
     Returns
     -------
     mod : module object
-       The module that was imported.
+        The module that was imported.
     """
-    if not isinstance(name, string_types):
+    if not isinstance(name, str):
         raise TypeError("import_item accepts strings, not '%s'." % type(name))
-    name = cast_bytes_py2(name)
-    parts = name.rsplit('.', 1)
+    parts = name.rsplit(".", 1)
     if len(parts) == 2:
         # called with 'foo.bar....'
         package, obj = parts
         module = __import__(package, fromlist=[obj])
         try:
             pak = getattr(module, obj)
-        except AttributeError:
-            raise ImportError('No module named %s' % obj)
+        except AttributeError as e:
+            raise ImportError("No module named %s" % obj) from e
         return pak
     else:
         # called with un-dotted string
